# richardview

RichardView is a software tool for lab controls and automation. It was developed by Richard Randall at Stanford University.
It provides a GUI interface with data logging and automation capability for devices connected to a computer's serial ports.
One uses Python to write the 'widgets' that represent each device and to configure multiple instances of widgets into 'dashboards'.
The detailed documentation should be at richardview.readthedocs.io .
